@@ -44,6 +44,9 @@ extern crate base64;
 extern crate serde;
 extern crate serde_json;
 extern crate url;
+extern crate regex;
+#[macro_use] extern crate lazy_static;
+#[macro_use] extern crate if_chain;
 
 mod macros;
 
