@@ -39,8 +39,12 @@ fn test_bad_newline() {
     let mut reader = io::BufReader::new(StripHeaderReader::new(input));
     let mut text = String::new();
     match reader.read_line(&mut text) {
-        Err(err) => { assert_eq!(err.kind(), io::ErrorKind::InvalidData); }
-        Ok(_) => { panic!("Expected failure"); }
+        Err(err) => {
+            assert_eq!(err.kind(), io::ErrorKind::InvalidData);
+        }
+        Ok(_) => {
+            panic!("Expected failure");
+        }
     }
 }
 
@@ -54,9 +58,12 @@ fn test_basic_sourcemap() {
     }";
     let sm = SourceMap::from_reader(input).unwrap();
     let mut iter = sm.tokens().filter(|t| t.has_name());
-    assert_eq!(iter.next().unwrap().to_tuple(), ("coolstuff.js", 0, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(), ("coolstuff.js", 1, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(), ("coolstuff.js", 2, 2, Some("alert")));
+    assert_eq!(iter.next().unwrap().to_tuple(),
+               ("coolstuff.js", 0, 4, Some("x")));
+    assert_eq!(iter.next().unwrap().to_tuple(),
+               ("coolstuff.js", 1, 4, Some("x")));
+    assert_eq!(iter.next().unwrap().to_tuple(),
+               ("coolstuff.js", 2, 2, Some("alert")));
     assert!(iter.next().is_none());
 }
 
@@ -71,23 +78,34 @@ fn test_basic_sourcemap_with_root() {
     }";
     let sm = SourceMap::from_reader(input).unwrap();
     let mut iter = sm.tokens().filter(|t| t.has_name());
-    assert_eq!(iter.next().unwrap().to_tuple(), ("x/coolstuff.js", 0, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(), ("x/coolstuff.js", 1, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(), ("x/coolstuff.js", 2, 2, Some("alert")));
+    assert_eq!(iter.next().unwrap().to_tuple(),
+               ("x/coolstuff.js", 0, 4, Some("x")));
+    assert_eq!(iter.next().unwrap().to_tuple(),
+               ("x/coolstuff.js", 1, 4, Some("x")));
+    assert_eq!(iter.next().unwrap().to_tuple(),
+               ("x/coolstuff.js", 2, 2, Some("alert")));
     assert!(iter.next().is_none());
 }
 
 #[test]
 fn test_sourcemap_data_url() {
-    let url = "data:application/json;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbImNvb2xzdHVmZi5qcyJdLCJzb3VyY2VSb290IjoieCIsIm5hbWVzIjpbIngiLCJhbGVydCJdLCJtYXBwaW5ncyI6IkFBQUEsR0FBSUEsR0FBSSxFQUNSLElBQUlBLEdBQUssRUFBRyxDQUNWQyxNQUFNIn0=";
+    let url = "data:application/json;base64,\
+         eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbImNvb2xzdHVmZi5qcyJdLCJzb3VyY2VSb290I\
+         joieCIsIm5hbWVzIjpbIngiLCJhbGVydCJdLCJtYXBwaW5ncyI6IkFBQUEsR0FBSUEsR0\
+         FBSSxFQUNSLElBQUlBLEdBQUssRUFBRyxDQUNWQyxNQUFNIn0=";
     match decode_data_url(url).unwrap() {
         DecodedMap::Regular(sm) => {
             let mut iter = sm.tokens().filter(|t| t.has_name());
-            assert_eq!(iter.next().unwrap().to_tuple(), ("x/coolstuff.js", 0, 4, Some("x")));
-            assert_eq!(iter.next().unwrap().to_tuple(), ("x/coolstuff.js", 1, 4, Some("x")));
-            assert_eq!(iter.next().unwrap().to_tuple(), ("x/coolstuff.js", 2, 2, Some("alert")));
+            assert_eq!(iter.next().unwrap().to_tuple(),
+                       ("x/coolstuff.js", 0, 4, Some("x")));
+            assert_eq!(iter.next().unwrap().to_tuple(),
+                       ("x/coolstuff.js", 1, 4, Some("x")));
+            assert_eq!(iter.next().unwrap().to_tuple(),
+                       ("x/coolstuff.js", 2, 2, Some("alert")));
             assert!(iter.next().is_none());
-        },
-        _ => { panic!("did not get sourcemap"); }
+        }
+        _ => {
+            panic!("did not get sourcemap");
+        }
     }
 }
